# Brightway2 regionalized LCA

This package provides a regionalized LCA calculations for the [Brightway2 life cycle assessment framework](https://brightway.dev). [Online documentation](https://brightway2-regional.readthedocs.io/) is available, and the source code is hosted on [Github](https://github.com/brightway-lca/brightway2-regional).

## Contributors

* Chris Mutel (https://chris.mutel.org/)
* Estelle Louineau
